# colnade_dask

Dask backend adapter, I/O functions, and scan functions.

## DaskBackend

::: colnade_dask.adapter.DaskBackend

## I/O Functions

::: colnade_dask.io.read_parquet

::: colnade_dask.io.scan_parquet

::: colnade_dask.io.read_csv

::: colnade_dask.io.scan_csv

::: colnade_dask.io.write_parquet

::: colnade_dask.io.write_csv
